/*
 * include/asm-i386/serial.h
 */

#include <linux/config.h>

/*
 * This assumes you have a 1.8432 MHz clock for your UART.
 *
 * It'd be nice if someone built a serial card with a 24.576 MHz
 * clock, since the 16550A is capable of handling a top speed of 1.5
 * megabits/second; but this requires the faster clock.
 */
#define BASE_BAUD ( 1843200 / 16 )

/* Standard COM flags (except for COM4, because of the 8514 problem) */
#ifdef CONFIG_SERIAL_DETECT_IRQ
#define STD_COM_FLAGS (ASYNC_BOOT_AUTOCONF | ASYNC_SKIP_TEST | ASYNC_AUTO_IRQ)
#define STD_COM4_FLAGS (ASYNC_BOOT_AUTOCONF | ASYNC_AUTO_IRQ)
#else
#define STD_COM_FLAGS (ASYNC_BOOT_AUTOCONF | ASYNC_SKIP_TEST)
#define STD_COM4_FLAGS ASYNC_BOOT_AUTOCONF
#endif

#ifdef CONFIG_SERIAL_MANY_PORTS
#define FOURPORT_FLAGS ASYNC_FOURPORT
#define ACCENT_FLAGS 0
#define BOCA_FLAGS 0
#define HUB6_FLAGS 0
#endif
	
/*
 * The following define the access methods for the HUB6 card. All
 * access is through two ports for all 24 possible chips. The card is
 * selected through the high 2 bits, the port on that card with the
 * "middle" 3 bits, and the register on that port with the bottom
 * 3 bits.
 *
 * While the access port and interrupt is configurable, the default
 * port locations are 0x302 for the port control register, and 0x303
 * for the data read/write register. Normally, the interrupt is at irq3
 * but can be anything from 3 to 7 inclusive. Note that using 3 will
 * require disabling com2.
 */

#define C_P(card,port) (((card)<<6|(port)<<3) + 1)

/*
 * Decision PCCOM PCI 2/4/8-port cards support
 *
 * You can have up to two cards in the system.
 */
#if (defined(CONFIG_DCIPCCOM_PCI) && defined(CONFIG_SERIAL_MANY_PORTS))

#define DCIPCCOM_PCI_SERIAL_PORT_DFNS	\
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ0 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ1 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ2 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ3 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ4 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ5 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ6 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ7 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ8 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ9 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ10 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ11 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ12 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ13 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ14 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ15 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ16 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ17 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ18 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ19 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ20 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ21 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ22 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ23 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ24 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ25 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ26 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ27 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ28 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ29 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ30 */ \
        { 0, BASE_BAUD, 0x0, 0, STD_COM_FLAGS },	/* ttyZ31 */
#else
#define DCIPCCOM_PCI_SERIAL_PORT_DFNS
#endif

#define SERIAL_PORT_DFNS		\
	DCIPCCOM_PCI_SERIAL_PORT_DFNS	\

